/*
 * Quasseldroid - Quassel client for Android
 *
 * Copyright (c) 2021 Janne Mareike Koschinski
 * Copyright (c) 2021 The Quassel Project
 *
 * This program is free software: you can redistribute it and/or modify it
 * under the terms of the GNU General Public License version 3 as published
 * by the Free Software Foundation.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License along
 * with this program. If not, see <http://www.gnu.org/licenses/>.
 */
package de.justjanne.libquassel.protocol.serializers.handshake

import de.justjanne.libquassel.protocol.features.FeatureSet
import de.justjanne.libquassel.protocol.models.BackendInfo
import de.justjanne.libquassel.protocol.models.HandshakeMessage
import de.justjanne.libquassel.protocol.models.SetupEntry
import de.justjanne.libquassel.protocol.models.types.QtType
import de.justjanne.libquassel.protocol.testutil.byteBufferOf
import de.justjanne.libquassel.protocol.testutil.handshakeSerializerTest
import de.justjanne.libquassel.protocol.variant.qVariant
import org.junit.jupiter.api.Tag
import org.junit.jupiter.api.Test

@Tag("HandshakeSerializerTest")
class ClientInitAckSerializerTest {
  @Test
  fun testEmptyMap() = handshakeSerializerTest(
    HandshakeMessage.ClientInitAck(
      coreConfigured = null,
      backendInfo = emptyList(),
      authenticatorInfo = emptyList(),
      featureSet = FeatureSet.none()
    ),
    byteBufferOf(
      // 4 elements
      0x00u, 0x00u, 0x00u, 0x02u,
      // ByteBuffer
      0x00u, 0x00u, 0x00u, 0x0Cu,
      0x00u,
      // 7 bytes
      0x00u, 0x00u, 0x00u, 0x07u,
      // MsgType
      0x4Du, 0x73u, 0x67u, 0x54u, 0x79u, 0x70u, 0x65u,
      // String
      0x00u, 0x00u, 0x00u, 0x0Au,
      0x00u,
      // 13 2-byte chars
      0x00u, 0x00u, 0x00u, 0x1Au,
      // ClientInitAck
      0x00u, 0x43u, 0x00u, 0x6Cu, 0x00u, 0x69u, 0x00u, 0x65u, 0x00u, 0x6Eu, 0x00u, 0x74u, 0x00u, 0x49u, 0x00u, 0x6Eu,
      0x00u, 0x69u, 0x00u, 0x74u, 0x00u, 0x41u, 0x00u, 0x63u, 0x00u, 0x6Bu,
    ),
    featureSets = emptyList(),
    serializeFeatureSet = null
  )

  @Test
  fun testSimple() = handshakeSerializerTest(
    HandshakeMessage.ClientInitAck(
      coreConfigured = false,
      backendInfo = emptyList(),
      authenticatorInfo = emptyList(),
      featureSet = FeatureSet.none()
    ),
    byteBufferOf(
      0x00u, 0x00u, 0x00u, 0x0Cu, 0x00u, 0x00u, 0x00u, 0x0Cu, 0x00u, 0x00u, 0x00u, 0x00u, 0x07u, 0x4Du, 0x73u, 0x67u,
      0x54u, 0x79u, 0x70u, 0x65u, 0x00u, 0x00u, 0x00u, 0x0Au, 0x00u, 0x00u, 0x00u, 0x00u, 0x1Au, 0x00u, 0x43u, 0x00u,
      0x6Cu, 0x00u, 0x69u, 0x00u, 0x65u, 0x00u, 0x6Eu, 0x00u, 0x74u, 0x00u, 0x49u, 0x00u, 0x6Eu, 0x00u, 0x69u, 0x00u,
      0x74u, 0x00u, 0x41u, 0x00u, 0x63u, 0x00u, 0x6Bu, 0x00u, 0x00u, 0x00u, 0x0Cu, 0x00u, 0x00u, 0x00u, 0x00u, 0x0Cu,
      0x43u, 0x6Fu, 0x72u, 0x65u, 0x46u, 0x65u, 0x61u, 0x74u, 0x75u, 0x72u, 0x65u, 0x73u, 0x00u, 0x00u, 0x00u, 0x03u,
      0x00u, 0x00u, 0x00u, 0x00u, 0x00u, 0x00u, 0x00u, 0x00u, 0x0Cu, 0x00u, 0x00u, 0x00u, 0x00u, 0x0Fu, 0x53u, 0x74u,
      0x6Fu, 0x72u, 0x61u, 0x67u, 0x65u, 0x42u, 0x61u, 0x63u, 0x6Bu, 0x65u, 0x6Eu, 0x64u, 0x73u, 0x00u, 0x00u, 0x00u,
      0x09u, 0x00u, 0x00u, 0x00u, 0x00u, 0x00u, 0x00u, 0x00u, 0x00u, 0x0Cu, 0x00u, 0x00u, 0x00u, 0x00u, 0x0Du, 0x41u,
      0x75u, 0x74u, 0x68u, 0x65u, 0x6Eu, 0x74u, 0x69u, 0x63u, 0x61u, 0x74u, 0x6Fu, 0x72u, 0x00u, 0x00u, 0x00u, 0x09u,
      0x00u, 0x00u, 0x00u, 0x00u, 0x00u, 0x00u, 0x00u, 0x00u, 0x0Cu, 0x00u, 0x00u, 0x00u, 0x00u, 0x0Au, 0x43u, 0x6Fu,
      0x6Eu, 0x66u, 0x69u, 0x67u, 0x75u, 0x72u, 0x65u, 0x64u, 0x00u, 0x00u, 0x00u, 0x01u, 0x00u, 0x00u, 0x00u, 0x00u,
      0x00u, 0x0Cu, 0x00u, 0x00u, 0x00u, 0x00u, 0x0Bu, 0x46u, 0x65u, 0x61u, 0x74u, 0x75u, 0x72u, 0x65u, 0x4Cu, 0x69u,
      0x73u, 0x74u, 0x00u, 0x00u, 0x00u, 0x0Bu, 0x00u, 0x00u, 0x00u, 0x00u, 0x00u,
    )
  )

  @Test
  fun testRealistic() = handshakeSerializerTest(
    HandshakeMessage.ClientInitAck(
      coreConfigured = false,
      backendInfo = listOf(
        BackendInfo(
          entries = emptyList(),
          isDefault = true,
          displayName = "SQLite",
          description = "SQLite is a file-based database engine that does not " +
            "require any setup. It is suitable for small and medium-sized " +
            "databases that do not require access via network. Use SQLite if " +
            "your Quassel Core should store its data on the same machine it is " +
            "running on, and if you only expect a few users to use your core.",
          backendId = "SQLite"
        ),
        BackendInfo(
          entries = listOf(
            SetupEntry(
              "Username",
              "Username",
              qVariant("quassel", QtType.QString)
            ),
            SetupEntry(
              "Password",
              "Password",
              qVariant<String?>(null, QtType.QString)
            ),
            SetupEntry(
              "Hostname",
              "Hostname",
              qVariant("localhost", QtType.QString)
            ),
            SetupEntry(
              "Port",
              "Port",
              qVariant(5432, QtType.Int)
            ),
            SetupEntry(
              "Database",
              "Database",
              qVariant("quassel", QtType.QString)
            )
          ),
          isDefault = false,
          displayName = "PostgreSQL",
          description = "PostgreSQL Turbo Bomber HD!",
          backendId = "PostgreSQL"
        )
      ),
      authenticatorInfo = listOf(
        BackendInfo(
          entries = emptyList(),
          isDefault = true,
          displayName = "Database",
          description = "Do not authenticate against any remote service, but " +
            "instead save a hashed and salted password in the database " +
            "selected in the next step.",
          backendId = "Database"
        ),
        BackendInfo(
          entries = listOf(
            SetupEntry(
              "Hostname",
              "Hostname",
              qVariant("ldap://localhost", QtType.QString),
            ),
            SetupEntry(
              "Port",
              "Port",
              qVariant(389, QtType.Int),
            ),
            SetupEntry(
              "BindDN",
              "Bind DN",
              qVariant<String?>(null, QtType.QString),
            ),
            SetupEntry(
              "BindPassword",
              "Bind Password",
              qVariant<String?>(null, QtType.QString),
            ),
            SetupEntry(
              "BaseDN",
              "Base DN",
              qVariant<String?>(null, QtType.QString),
            ),
            SetupEntry(
              "Filter",
              "Filter",
              qVariant<String?>(null, QtType.QString),
            ),
            SetupEntry(
              "UidAttribute",
              "UID Attribute",
              qVariant("uid", QtType.QString),
            )
          ),
          isDefault = false,
          displayName = "LDAP",
          description = "Authenticate users using an LDAP server.",
          backendId = "LDAP"
        )
      ),
      featureSet = FeatureSet.none()
    ),
    byteBufferOf(
      0x00u, 0x00u, 0x00u, 0x0Cu, 0x00u, 0x00u, 0x00u, 0x0Cu, 0x00u, 0x00u, 0x00u, 0x00u, 0x07u, 0x4Du, 0x73u, 0x67u,
      0x54u, 0x79u, 0x70u, 0x65u, 0x00u, 0x00u, 0x00u, 0x0Au, 0x00u, 0x00u, 0x00u, 0x00u, 0x1Au, 0x00u, 0x43u, 0x00u,
      0x6Cu, 0x00u, 0x69u, 0x00u, 0x65u, 0x00u, 0x6Eu, 0x00u, 0x74u, 0x00u, 0x49u, 0x00u, 0x6Eu, 0x00u, 0x69u, 0x00u,
      0x74u, 0x00u, 0x41u, 0x00u, 0x63u, 0x00u, 0x6Bu, 0x00u, 0x00u, 0x00u, 0x0Cu, 0x00u, 0x00u, 0x00u, 0x00u, 0x0Cu,
      0x43u, 0x6Fu, 0x72u, 0x65u, 0x46u, 0x65u, 0x61u, 0x74u, 0x75u, 0x72u, 0x65u, 0x73u, 0x00u, 0x00u, 0x00u, 0x03u,
      0x00u, 0x00u, 0x00u, 0x00u, 0x00u, 0x00u, 0x00u, 0x00u, 0x0Cu, 0x00u, 0x00u, 0x00u, 0x00u, 0x0Fu, 0x53u, 0x74u,
      0x6Fu, 0x72u, 0x61u, 0x67u, 0x65u, 0x42u, 0x61u, 0x63u, 0x6Bu, 0x65u, 0x6Eu, 0x64u, 0x73u, 0x00u, 0x00u, 0x00u,
      0x09u, 0x00u, 0x00u, 0x00u, 0x00u, 0x02u, 0x00u, 0x00u, 0x00u, 0x08u, 0x00u, 0x00u, 0x00u, 0x00u, 0x07u, 0x00u,
      0x00u, 0x00u, 0x12u, 0x00u, 0x53u, 0x00u, 0x65u, 0x00u, 0x74u, 0x00u, 0x75u, 0x00u, 0x70u, 0x00u, 0x4Bu, 0x00u,
      0x65u, 0x00u, 0x79u, 0x00u, 0x73u, 0x00u, 0x00u, 0x00u, 0x0Bu, 0x00u, 0x00u, 0x00u, 0x00u, 0x00u, 0x00u, 0x00u,
      0x00u, 0x1Au, 0x00u, 0x53u, 0x00u, 0x65u, 0x00u, 0x74u, 0x00u, 0x75u, 0x00u, 0x70u, 0x00u, 0x44u, 0x00u, 0x65u,
      0x00u, 0x66u, 0x00u, 0x61u, 0x00u, 0x75u, 0x00u, 0x6Cu, 0x00u, 0x74u, 0x00u, 0x73u, 0x00u, 0x00u, 0x00u, 0x08u,
      0x00u, 0x00u, 0x00u, 0x00u, 0x00u, 0x00u, 0x00u, 0x00u, 0x12u, 0x00u, 0x53u, 0x00u, 0x65u, 0x00u, 0x74u, 0x00u,
      0x75u, 0x00u, 0x70u, 0x00u, 0x44u, 0x00u, 0x61u, 0x00u, 0x74u, 0x00u, 0x61u, 0x00u, 0x00u, 0x00u, 0x09u, 0x00u,
      0x00u, 0x00u, 0x00u, 0x00u, 0x00u, 0x00u, 0x00u, 0x12u, 0x00u, 0x49u, 0x00u, 0x73u, 0x00u, 0x44u, 0x00u, 0x65u,
      0x00u, 0x66u, 0x00u, 0x61u, 0x00u, 0x75u, 0x00u, 0x6Cu, 0x00u, 0x74u, 0x00u, 0x00u, 0x00u, 0x01u, 0x00u, 0x01u,
      0x00u, 0x00u, 0x00u, 0x16u, 0x00u, 0x44u, 0x00u, 0x69u, 0x00u, 0x73u, 0x00u, 0x70u, 0x00u, 0x6Cu, 0x00u, 0x61u,
      0x00u, 0x79u, 0x00u, 0x4Eu, 0x00u, 0x61u, 0x00u, 0x6Du, 0x00u, 0x65u, 0x00u, 0x00u, 0x00u, 0x0Au, 0x00u, 0x00u,
      0x00u, 0x00u, 0x0Cu, 0x00u, 0x53u, 0x00u, 0x51u, 0x00u, 0x4Cu, 0x00u, 0x69u, 0x00u, 0x74u, 0x00u, 0x65u, 0x00u,
      0x00u, 0x00u, 0x16u, 0x00u, 0x44u, 0x00u, 0x65u, 0x00u, 0x73u, 0x00u, 0x63u, 0x00u, 0x72u, 0x00u, 0x69u, 0x00u,
      0x70u, 0x00u, 0x74u, 0x00u, 0x69u, 0x00u, 0x6Fu, 0x00u, 0x6Eu, 0x00u, 0x00u, 0x00u, 0x0Au, 0x00u, 0x00u, 0x00u,
      0x02u, 0x68u, 0x00u, 0x53u, 0x00u, 0x51u, 0x00u, 0x4Cu, 0x00u, 0x69u, 0x00u, 0x74u, 0x00u, 0x65u, 0x00u, 0x20u,
      0x00u, 0x69u, 0x00u, 0x73u, 0x00u, 0x20u, 0x00u, 0x61u, 0x00u, 0x20u, 0x00u, 0x66u, 0x00u, 0x69u, 0x00u, 0x6Cu,
      0x00u, 0x65u, 0x00u, 0x2Du, 0x00u, 0x62u, 0x00u, 0x61u, 0x00u, 0x73u, 0x00u, 0x65u, 0x00u, 0x64u, 0x00u, 0x20u,
      0x00u, 0x64u, 0x00u, 0x61u, 0x00u, 0x74u, 0x00u, 0x61u, 0x00u, 0x62u, 0x00u, 0x61u, 0x00u, 0x73u, 0x00u, 0x65u,
      0x00u, 0x20u, 0x00u, 0x65u, 0x00u, 0x6Eu, 0x00u, 0x67u, 0x00u, 0x69u, 0x00u, 0x6Eu, 0x00u, 0x65u, 0x00u, 0x20u,
      0x00u, 0x74u, 0x00u, 0x68u, 0x00u, 0x61u, 0x00u, 0x74u, 0x00u, 0x20u, 0x00u, 0x64u, 0x00u, 0x6Fu, 0x00u, 0x65u,
      0x00u, 0x73u, 0x00u, 0x20u, 0x00u, 0x6Eu, 0x00u, 0x6Fu, 0x00u, 0x74u, 0x00u, 0x20u, 0x00u, 0x72u, 0x00u, 0x65u,
      0x00u, 0x71u, 0x00u, 0x75u, 0x00u, 0x69u, 0x00u, 0x72u, 0x00u, 0x65u, 0x00u, 0x20u, 0x00u, 0x61u, 0x00u, 0x6Eu,
      0x00u, 0x79u, 0x00u, 0x20u, 0x00u, 0x73u, 0x00u, 0x65u, 0x00u, 0x74u, 0x00u, 0x75u, 0x00u, 0x70u, 0x00u, 0x2Eu,
      0x00u, 0x20u, 0x00u, 0x49u, 0x00u, 0x74u, 0x00u, 0x20u, 0x00u, 0x69u, 0x00u, 0x73u, 0x00u, 0x20u, 0x00u, 0x73u,
      0x00u, 0x75u, 0x00u, 0x69u, 0x00u, 0x74u, 0x00u, 0x61u, 0x00u, 0x62u, 0x00u, 0x6Cu, 0x00u, 0x65u, 0x00u, 0x20u,
      0x00u, 0x66u, 0x00u, 0x6Fu, 0x00u, 0x72u, 0x00u, 0x20u, 0x00u, 0x73u, 0x00u, 0x6Du, 0x00u, 0x61u, 0x00u, 0x6Cu,
      0x00u, 0x6Cu, 0x00u, 0x20u, 0x00u, 0x61u, 0x00u, 0x6Eu, 0x00u, 0x64u, 0x00u, 0x20u, 0x00u, 0x6Du, 0x00u, 0x65u,
      0x00u, 0x64u, 0x00u, 0x69u, 0x00u, 0x75u, 0x00u, 0x6Du, 0x00u, 0x2Du, 0x00u, 0x73u, 0x00u, 0x69u, 0x00u, 0x7Au,
      0x00u, 0x65u, 0x00u, 0x64u, 0x00u, 0x20u, 0x00u, 0x64u, 0x00u, 0x61u, 0x00u, 0x74u, 0x00u, 0x61u, 0x00u, 0x62u,
      0x00u, 0x61u, 0x00u, 0x73u, 0x00u, 0x65u, 0x00u, 0x73u, 0x00u, 0x20u, 0x00u, 0x74u, 0x00u, 0x68u, 0x00u, 0x61u,
      0x00u, 0x74u, 0x00u, 0x20u, 0x00u, 0x64u, 0x00u, 0x6Fu, 0x00u, 0x20u, 0x00u, 0x6Eu, 0x00u, 0x6Fu, 0x00u, 0x74u,
      0x00u, 0x20u, 0x00u, 0x72u, 0x00u, 0x65u, 0x00u, 0x71u, 0x00u, 0x75u, 0x00u, 0x69u, 0x00u, 0x72u, 0x00u, 0x65u,
      0x00u, 0x20u, 0x00u, 0x61u, 0x00u, 0x63u, 0x00u, 0x63u, 0x00u, 0x65u, 0x00u, 0x73u, 0x00u, 0x73u, 0x00u, 0x20u,
      0x00u, 0x76u, 0x00u, 0x69u, 0x00u, 0x61u, 0x00u, 0x20u, 0x00u, 0x6Eu, 0x00u, 0x65u, 0x00u, 0x74u, 0x00u, 0x77u,
      0x00u, 0x6Fu, 0x00u, 0x72u, 0x00u, 0x6Bu, 0x00u, 0x2Eu, 0x00u, 0x20u, 0x00u, 0x55u, 0x00u, 0x73u, 0x00u, 0x65u,
      0x00u, 0x20u, 0x00u, 0x53u, 0x00u, 0x51u, 0x00u, 0x4Cu, 0x00u, 0x69u, 0x00u, 0x74u, 0x00u, 0x65u, 0x00u, 0x20u,
      0x00u, 0x69u, 0x00u, 0x66u, 0x00u, 0x20u, 0x00u, 0x79u, 0x00u, 0x6Fu, 0x00u, 0x75u, 0x00u, 0x72u, 0x00u, 0x20u,
      0x00u, 0x51u, 0x00u, 0x75u, 0x00u, 0x61u, 0x00u, 0x73u, 0x00u, 0x73u, 0x00u, 0x65u, 0x00u, 0x6Cu, 0x00u, 0x20u,
      0x00u, 0x43u, 0x00u, 0x6Fu, 0x00u, 0x72u, 0x00u, 0x65u, 0x00u, 0x20u, 0x00u, 0x73u, 0x00u, 0x68u, 0x00u, 0x6Fu,
      0x00u, 0x75u, 0x00u, 0x6Cu, 0x00u, 0x64u, 0x00u, 0x20u, 0x00u, 0x73u, 0x00u, 0x74u, 0x00u, 0x6Fu, 0x00u, 0x72u,
      0x00u, 0x65u, 0x00u, 0x20u, 0x00u, 0x69u, 0x00u, 0x74u, 0x00u, 0x73u, 0x00u, 0x20u, 0x00u, 0x64u, 0x00u, 0x61u,
      0x00u, 0x74u, 0x00u, 0x61u, 0x00u, 0x20u, 0x00u, 0x6Fu, 0x00u, 0x6Eu, 0x00u, 0x20u, 0x00u, 0x74u, 0x00u, 0x68u,
      0x00u, 0x65u, 0x00u, 0x20u, 0x00u, 0x73u, 0x00u, 0x61u, 0x00u, 0x6Du, 0x00u, 0x65u, 0x00u, 0x20u, 0x00u, 0x6Du,
      0x00u, 0x61u, 0x00u, 0x63u, 0x00u, 0x68u, 0x00u, 0x69u, 0x00u, 0x6Eu, 0x00u, 0x65u, 0x00u, 0x20u, 0x00u, 0x69u,
      0x00u, 0x74u, 0x00u, 0x20u, 0x00u, 0x69u, 0x00u, 0x73u, 0x00u, 0x20u, 0x00u, 0x72u, 0x00u, 0x75u, 0x00u, 0x6Eu,
      0x00u, 0x6Eu, 0x00u, 0x69u, 0x00u, 0x6Eu, 0x00u, 0x67u, 0x00u, 0x20u, 0x00u, 0x6Fu, 0x00u, 0x6Eu, 0x00u, 0x2Cu,
      0x00u, 0x20u, 0x00u, 0x61u, 0x00u, 0x6Eu, 0x00u, 0x64u, 0x00u, 0x20u, 0x00u, 0x69u, 0x00u, 0x66u, 0x00u, 0x20u,
      0x00u, 0x79u, 0x00u, 0x6Fu, 0x00u, 0x75u, 0x00u, 0x20u, 0x00u, 0x6Fu, 0x00u, 0x6Eu, 0x00u, 0x6Cu, 0x00u, 0x79u,
      0x00u, 0x20u, 0x00u, 0x65u, 0x00u, 0x78u, 0x00u, 0x70u, 0x00u, 0x65u, 0x00u, 0x63u, 0x00u, 0x74u, 0x00u, 0x20u,
      0x00u, 0x61u, 0x00u, 0x20u, 0x00u, 0x66u, 0x00u, 0x65u, 0x00u, 0x77u, 0x00u, 0x20u, 0x00u, 0x75u, 0x00u, 0x73u,
      0x00u, 0x65u, 0x00u, 0x72u, 0x00u, 0x73u, 0x00u, 0x20u, 0x00u, 0x74u, 0x00u, 0x6Fu, 0x00u, 0x20u, 0x00u, 0x75u,
      0x00u, 0x73u, 0x00u, 0x65u, 0x00u, 0x20u, 0x00u, 0x79u, 0x00u, 0x6Fu, 0x00u, 0x75u, 0x00u, 0x72u, 0x00u, 0x20u,
      0x00u, 0x63u, 0x00u, 0x6Fu, 0x00u, 0x72u, 0x00u, 0x65u, 0x00u, 0x2Eu, 0x00u, 0x00u, 0x00u, 0x12u, 0x00u, 0x42u,
      0x00u, 0x61u, 0x00u, 0x63u, 0x00u, 0x6Bu, 0x00u, 0x65u, 0x00u, 0x6Eu, 0x00u, 0x64u, 0x00u, 0x49u, 0x00u, 0x64u,
      0x00u, 0x00u, 0x00u, 0x0Au, 0x00u, 0x00u, 0x00u, 0x00u, 0x0Cu, 0x00u, 0x53u, 0x00u, 0x51u, 0x00u, 0x4Cu, 0x00u,
      0x69u, 0x00u, 0x74u, 0x00u, 0x65u, 0x00u, 0x00u, 0x00u, 0x08u, 0x00u, 0x00u, 0x00u, 0x00u, 0x07u, 0x00u, 0x00u,
      0x00u, 0x12u, 0x00u, 0x53u, 0x00u, 0x65u, 0x00u, 0x74u, 0x00u, 0x75u, 0x00u, 0x70u, 0x00u, 0x4Bu, 0x00u, 0x65u,
      0x00u, 0x79u, 0x00u, 0x73u, 0x00u, 0x00u, 0x00u, 0x0Bu, 0x00u, 0x00u, 0x00u, 0x00u, 0x05u, 0x00u, 0x00u, 0x00u,
      0x10u, 0x00u, 0x55u, 0x00u, 0x73u, 0x00u, 0x65u, 0x00u, 0x72u, 0x00u, 0x6Eu, 0x00u, 0x61u, 0x00u, 0x6Du, 0x00u,
      0x65u, 0x00u, 0x00u, 0x00u, 0x10u, 0x00u, 0x50u, 0x00u, 0x61u, 0x00u, 0x73u, 0x00u, 0x73u, 0x00u, 0x77u, 0x00u,
      0x6Fu, 0x00u, 0x72u, 0x00u, 0x64u, 0x00u, 0x00u, 0x00u, 0x10u, 0x00u, 0x48u, 0x00u, 0x6Fu, 0x00u, 0x73u, 0x00u,
      0x74u, 0x00u, 0x6Eu, 0x00u, 0x61u, 0x00u, 0x6Du, 0x00u, 0x65u, 0x00u, 0x00u, 0x00u, 0x08u, 0x00u, 0x50u, 0x00u,
      0x6Fu, 0x00u, 0x72u, 0x00u, 0x74u, 0x00u, 0x00u, 0x00u, 0x10u, 0x00u, 0x44u, 0x00u, 0x61u, 0x00u, 0x74u, 0x00u,
      0x61u, 0x00u, 0x62u, 0x00u, 0x61u, 0x00u, 0x73u, 0x00u, 0x65u, 0x00u, 0x00u, 0x00u, 0x1Au, 0x00u, 0x53u, 0x00u,
      0x65u, 0x00u, 0x74u, 0x00u, 0x75u, 0x00u, 0x70u, 0x00u, 0x44u, 0x00u, 0x65u, 0x00u, 0x66u, 0x00u, 0x61u, 0x00u,
      0x75u, 0x00u, 0x6Cu, 0x00u, 0x74u, 0x00u, 0x73u, 0x00u, 0x00u, 0x00u, 0x08u, 0x00u, 0x00u, 0x00u, 0x00u, 0x05u,
      0x00u, 0x00u, 0x00u, 0x10u, 0x00u, 0x55u, 0x00u, 0x73u, 0x00u, 0x65u, 0x00u, 0x72u, 0x00u, 0x6Eu, 0x00u, 0x61u,
      0x00u, 0x6Du, 0x00u, 0x65u, 0x00u, 0x00u, 0x00u, 0x0Au, 0x00u, 0x00u, 0x00u, 0x00u, 0x0Eu, 0x00u, 0x71u, 0x00u,
      0x75u, 0x00u, 0x61u, 0x00u, 0x73u, 0x00u, 0x73u, 0x00u, 0x65u, 0x00u, 0x6Cu, 0x00u, 0x00u, 0x00u, 0x10u, 0x00u,
      0x50u, 0x00u, 0x61u, 0x00u, 0x73u, 0x00u, 0x73u, 0x00u, 0x77u, 0x00u, 0x6Fu, 0x00u, 0x72u, 0x00u, 0x64u, 0x00u,
      0x00u, 0x00u, 0x0Au, 0x00u, 0xFFu, 0xFFu, 0xFFu, 0xFFu, 0x00u, 0x00u, 0x00u, 0x10u, 0x00u, 0x48u, 0x00u, 0x6Fu,
      0x00u, 0x73u, 0x00u, 0x74u, 0x00u, 0x6Eu, 0x00u, 0x61u, 0x00u, 0x6Du, 0x00u, 0x65u, 0x00u, 0x00u, 0x00u, 0x0Au,
      0x00u, 0x00u, 0x00u, 0x00u, 0x12u, 0x00u, 0x6Cu, 0x00u, 0x6Fu, 0x00u, 0x63u, 0x00u, 0x61u, 0x00u, 0x6Cu, 0x00u,
      0x68u, 0x00u, 0x6Fu, 0x00u, 0x73u, 0x00u, 0x74u, 0x00u, 0x00u, 0x00u, 0x08u, 0x00u, 0x50u, 0x00u, 0x6Fu, 0x00u,
      0x72u, 0x00u, 0x74u, 0x00u, 0x00u, 0x00u, 0x02u, 0x00u, 0x00u, 0x00u, 0x15u, 0x38u, 0x00u, 0x00u, 0x00u, 0x10u,
      0x00u, 0x44u, 0x00u, 0x61u, 0x00u, 0x74u, 0x00u, 0x61u, 0x00u, 0x62u, 0x00u, 0x61u, 0x00u, 0x73u, 0x00u, 0x65u,
      0x00u, 0x00u, 0x00u, 0x0Au, 0x00u, 0x00u, 0x00u, 0x00u, 0x0Eu, 0x00u, 0x71u, 0x00u, 0x75u, 0x00u, 0x61u, 0x00u,
      0x73u, 0x00u, 0x73u, 0x00u, 0x65u, 0x00u, 0x6Cu, 0x00u, 0x00u, 0x00u, 0x12u, 0x00u, 0x53u, 0x00u, 0x65u, 0x00u,
      0x74u, 0x00u, 0x75u, 0x00u, 0x70u, 0x00u, 0x44u, 0x00u, 0x61u, 0x00u, 0x74u, 0x00u, 0x61u, 0x00u, 0x00u, 0x00u,
      0x09u, 0x00u, 0x00u, 0x00u, 0x00u, 0x0Fu, 0x00u, 0x00u, 0x00u, 0x0Au, 0x00u, 0x00u, 0x00u, 0x00u, 0x10u, 0x00u,
      0x55u, 0x00u, 0x73u, 0x00u, 0x65u, 0x00u, 0x72u, 0x00u, 0x6Eu, 0x00u, 0x61u, 0x00u, 0x6Du, 0x00u, 0x65u, 0x00u,
      0x00u, 0x00u, 0x0Au, 0x00u, 0x00u, 0x00u, 0x00u, 0x10u, 0x00u, 0x55u, 0x00u, 0x73u, 0x00u, 0x65u, 0x00u, 0x72u,
      0x00u, 0x6Eu, 0x00u, 0x61u, 0x00u, 0x6Du, 0x00u, 0x65u, 0x00u, 0x00u, 0x00u, 0x0Au, 0x00u, 0x00u, 0x00u, 0x00u,
      0x0Eu, 0x00u, 0x71u, 0x00u, 0x75u, 0x00u, 0x61u, 0x00u, 0x73u, 0x00u, 0x73u, 0x00u, 0x65u, 0x00u, 0x6Cu, 0x00u,
      0x00u, 0x00u, 0x0Au, 0x00u, 0x00u, 0x00u, 0x00u, 0x10u, 0x00u, 0x50u, 0x00u, 0x61u, 0x00u, 0x73u, 0x00u, 0x73u,
      0x00u, 0x77u, 0x00u, 0x6Fu, 0x00u, 0x72u, 0x00u, 0x64u, 0x00u, 0x00u, 0x00u, 0x0Au, 0x00u, 0x00u, 0x00u, 0x00u,
      0x10u, 0x00u, 0x50u, 0x00u, 0x61u, 0x00u, 0x73u, 0x00u, 0x73u, 0x00u, 0x77u, 0x00u, 0x6Fu, 0x00u, 0x72u, 0x00u,
      0x64u, 0x00u, 0x00u, 0x00u, 0x0Au, 0x00u, 0xFFu, 0xFFu, 0xFFu, 0xFFu, 0x00u, 0x00u, 0x00u, 0x0Au, 0x00u, 0x00u,
      0x00u, 0x00u, 0x10u, 0x00u, 0x48u, 0x00u, 0x6Fu, 0x00u, 0x73u, 0x00u, 0x74u, 0x00u, 0x6Eu, 0x00u, 0x61u, 0x00u,
      0x6Du, 0x00u, 0x65u, 0x00u, 0x00u, 0x00u, 0x0Au, 0x00u, 0x00u, 0x00u, 0x00u, 0x10u, 0x00u, 0x48u, 0x00u, 0x6Fu,
      0x00u, 0x73u, 0x00u, 0x74u, 0x00u, 0x6Eu, 0x00u, 0x61u, 0x00u, 0x6Du, 0x00u, 0x65u, 0x00u, 0x00u, 0x00u, 0x0Au,
      0x00u, 0x00u, 0x00u, 0x00u, 0x12u, 0x00u, 0x6Cu, 0x00u, 0x6Fu, 0x00u, 0x63u, 0x00u, 0x61u, 0x00u, 0x6Cu, 0x00u,
      0x68u, 0x00u, 0x6Fu, 0x00u, 0x73u, 0x00u, 0x74u, 0x00u, 0x00u, 0x00u, 0x0Au, 0x00u, 0x00u, 0x00u, 0x00u, 0x08u,
      0x00u, 0x50u, 0x00u, 0x6Fu, 0x00u, 0x72u, 0x00u, 0x74u, 0x00u, 0x00u, 0x00u, 0x0Au, 0x00u, 0x00u, 0x00u, 0x00u,
      0x08u, 0x00u, 0x50u, 0x00u, 0x6Fu, 0x00u, 0x72u, 0x00u, 0x74u, 0x00u, 0x00u, 0x00u, 0x02u, 0x00u, 0x00u, 0x00u,
      0x15u, 0x38u, 0x00u, 0x00u, 0x00u, 0x0Au, 0x00u, 0x00u, 0x00u, 0x00u, 0x10u, 0x00u, 0x44u, 0x00u, 0x61u, 0x00u,
      0x74u, 0x00u, 0x61u, 0x00u, 0x62u, 0x00u, 0x61u, 0x00u, 0x73u, 0x00u, 0x65u, 0x00u, 0x00u, 0x00u, 0x0Au, 0x00u,
      0x00u, 0x00u, 0x00u, 0x10u, 0x00u, 0x44u, 0x00u, 0x61u, 0x00u, 0x74u, 0x00u, 0x61u, 0x00u, 0x62u, 0x00u, 0x61u,
      0x00u, 0x73u, 0x00u, 0x65u, 0x00u, 0x00u, 0x00u, 0x0Au, 0x00u, 0x00u, 0x00u, 0x00u, 0x0Eu, 0x00u, 0x71u, 0x00u,
      0x75u, 0x00u, 0x61u, 0x00u, 0x73u, 0x00u, 0x73u, 0x00u, 0x65u, 0x00u, 0x6Cu, 0x00u, 0x00u, 0x00u, 0x12u, 0x00u,
      0x49u, 0x00u, 0x73u, 0x00u, 0x44u, 0x00u, 0x65u, 0x00u, 0x66u, 0x00u, 0x61u, 0x00u, 0x75u, 0x00u, 0x6Cu, 0x00u,
      0x74u, 0x00u, 0x00u, 0x00u, 0x01u, 0x00u, 0x00u, 0x00u, 0x00u, 0x00u, 0x16u, 0x00u, 0x44u, 0x00u, 0x69u, 0x00u,
      0x73u, 0x00u, 0x70u, 0x00u, 0x6Cu, 0x00u, 0x61u, 0x00u, 0x79u, 0x00u, 0x4Eu, 0x00u, 0x61u, 0x00u, 0x6Du, 0x00u,
      0x65u, 0x00u, 0x00u, 0x00u, 0x0Au, 0x00u, 0x00u, 0x00u, 0x00u, 0x14u, 0x00u, 0x50u, 0x00u, 0x6Fu, 0x00u, 0x73u,
      0x00u, 0x74u, 0x00u, 0x67u, 0x00u, 0x72u, 0x00u, 0x65u, 0x00u, 0x53u, 0x00u, 0x51u, 0x00u, 0x4Cu, 0x00u, 0x00u,
      0x00u, 0x16u, 0x00u, 0x44u, 0x00u, 0x65u, 0x00u, 0x73u, 0x00u, 0x63u, 0x00u, 0x72u, 0x00u, 0x69u, 0x00u, 0x70u,
      0x00u, 0x74u, 0x00u, 0x69u, 0x00u, 0x6Fu, 0x00u, 0x6Eu, 0x00u, 0x00u, 0x00u, 0x0Au, 0x00u, 0x00u, 0x00u, 0x00u,
      0x36u, 0x00u, 0x50u, 0x00u, 0x6Fu, 0x00u, 0x73u, 0x00u, 0x74u, 0x00u, 0x67u, 0x00u, 0x72u, 0x00u, 0x65u, 0x00u,
      0x53u, 0x00u, 0x51u, 0x00u, 0x4Cu, 0x00u, 0x20u, 0x00u, 0x54u, 0x00u, 0x75u, 0x00u, 0x72u, 0x00u, 0x62u, 0x00u,
      0x6Fu, 0x00u, 0x20u, 0x00u, 0x42u, 0x00u, 0x6Fu, 0x00u, 0x6Du, 0x00u, 0x62u, 0x00u, 0x65u, 0x00u, 0x72u, 0x00u,
      0x20u, 0x00u, 0x48u, 0x00u, 0x44u, 0x00u, 0x21u, 0x00u, 0x00u, 0x00u, 0x12u, 0x00u, 0x42u, 0x00u, 0x61u, 0x00u,
      0x63u, 0x00u, 0x6Bu, 0x00u, 0x65u, 0x00u, 0x6Eu, 0x00u, 0x64u, 0x00u, 0x49u, 0x00u, 0x64u, 0x00u, 0x00u, 0x00u,
      0x0Au, 0x00u, 0x00u, 0x00u, 0x00u, 0x14u, 0x00u, 0x50u, 0x00u, 0x6Fu, 0x00u, 0x73u, 0x00u, 0x74u, 0x00u, 0x67u,
      0x00u, 0x72u, 0x00u, 0x65u, 0x00u, 0x53u, 0x00u, 0x51u, 0x00u, 0x4Cu, 0x00u, 0x00u, 0x00u, 0x0Cu, 0x00u, 0x00u,
      0x00u, 0x00u, 0x0Du, 0x41u, 0x75u, 0x74u, 0x68u, 0x65u, 0x6Eu, 0x74u, 0x69u, 0x63u, 0x61u, 0x74u, 0x6Fu, 0x72u,
      0x00u, 0x00u, 0x00u, 0x09u, 0x00u, 0x00u, 0x00u, 0x00u, 0x02u, 0x00u, 0x00u, 0x00u, 0x08u, 0x00u, 0x00u, 0x00u,
      0x00u, 0x07u, 0x00u, 0x00u, 0x00u, 0x12u, 0x00u, 0x53u, 0x00u, 0x65u, 0x00u, 0x74u, 0x00u, 0x75u, 0x00u, 0x70u,
      0x00u, 0x4Bu, 0x00u, 0x65u, 0x00u, 0x79u, 0x00u, 0x73u, 0x00u, 0x00u, 0x00u, 0x0Bu, 0x00u, 0x00u, 0x00u, 0x00u,
      0x00u, 0x00u, 0x00u, 0x00u, 0x1Au, 0x00u, 0x53u, 0x00u, 0x65u, 0x00u, 0x74u, 0x00u, 0x75u, 0x00u, 0x70u, 0x00u,
      0x44u, 0x00u, 0x65u, 0x00u, 0x66u, 0x00u, 0x61u, 0x00u, 0x75u, 0x00u, 0x6Cu, 0x00u, 0x74u, 0x00u, 0x73u, 0x00u,
      0x00u, 0x00u, 0x08u, 0x00u, 0x00u, 0x00u, 0x00u, 0x00u, 0x00u, 0x00u, 0x00u, 0x12u, 0x00u, 0x53u, 0x00u, 0x65u,
      0x00u, 0x74u, 0x00u, 0x75u, 0x00u, 0x70u, 0x00u, 0x44u, 0x00u, 0x61u, 0x00u, 0x74u, 0x00u, 0x61u, 0x00u, 0x00u,
      0x00u, 0x09u, 0x00u, 0x00u, 0x00u, 0x00u, 0x00u, 0x00u, 0x00u, 0x00u, 0x12u, 0x00u, 0x49u, 0x00u, 0x73u, 0x00u,
      0x44u, 0x00u, 0x65u, 0x00u, 0x66u, 0x00u, 0x61u, 0x00u, 0x75u, 0x00u, 0x6Cu, 0x00u, 0x74u, 0x00u, 0x00u, 0x00u,
      0x01u, 0x00u, 0x01u, 0x00u, 0x00u, 0x00u, 0x16u, 0x00u, 0x44u, 0x00u, 0x69u, 0x00u, 0x73u, 0x00u, 0x70u, 0x00u,
      0x6Cu, 0x00u, 0x61u, 0x00u, 0x79u, 0x00u, 0x4Eu, 0x00u, 0x61u, 0x00u, 0x6Du, 0x00u, 0x65u, 0x00u, 0x00u, 0x00u,
      0x0Au, 0x00u, 0x00u, 0x00u, 0x00u, 0x10u, 0x00u, 0x44u, 0x00u, 0x61u, 0x00u, 0x74u, 0x00u, 0x61u, 0x00u, 0x62u,
      0x00u, 0x61u, 0x00u, 0x73u, 0x00u, 0x65u, 0x00u, 0x00u, 0x00u, 0x16u, 0x00u, 0x44u, 0x00u, 0x65u, 0x00u, 0x73u,
      0x00u, 0x63u, 0x00u, 0x72u, 0x00u, 0x69u, 0x00u, 0x70u, 0x00u, 0x74u, 0x00u, 0x69u, 0x00u, 0x6Fu, 0x00u, 0x6Eu,
      0x00u, 0x00u, 0x00u, 0x0Au, 0x00u, 0x00u, 0x00u, 0x01u, 0x10u, 0x00u, 0x44u, 0x00u, 0x6Fu, 0x00u, 0x20u, 0x00u,
      0x6Eu, 0x00u, 0x6Fu, 0x00u, 0x74u, 0x00u, 0x20u, 0x00u, 0x61u, 0x00u, 0x75u, 0x00u, 0x74u, 0x00u, 0x68u, 0x00u,
      0x65u, 0x00u, 0x6Eu, 0x00u, 0x74u, 0x00u, 0x69u, 0x00u, 0x63u, 0x00u, 0x61u, 0x00u, 0x74u, 0x00u, 0x65u, 0x00u,
      0x20u, 0x00u, 0x61u, 0x00u, 0x67u, 0x00u, 0x61u, 0x00u, 0x69u, 0x00u, 0x6Eu, 0x00u, 0x73u, 0x00u, 0x74u, 0x00u,
      0x20u, 0x00u, 0x61u, 0x00u, 0x6Eu, 0x00u, 0x79u, 0x00u, 0x20u, 0x00u, 0x72u, 0x00u, 0x65u, 0x00u, 0x6Du, 0x00u,
      0x6Fu, 0x00u, 0x74u, 0x00u, 0x65u, 0x00u, 0x20u, 0x00u, 0x73u, 0x00u, 0x65u, 0x00u, 0x72u, 0x00u, 0x76u, 0x00u,
      0x69u, 0x00u, 0x63u, 0x00u, 0x65u, 0x00u, 0x2Cu, 0x00u, 0x20u, 0x00u, 0x62u, 0x00u, 0x75u, 0x00u, 0x74u, 0x00u,
      0x20u, 0x00u, 0x69u, 0x00u, 0x6Eu, 0x00u, 0x73u, 0x00u, 0x74u, 0x00u, 0x65u, 0x00u, 0x61u, 0x00u, 0x64u, 0x00u,
      0x20u, 0x00u, 0x73u, 0x00u, 0x61u, 0x00u, 0x76u, 0x00u, 0x65u, 0x00u, 0x20u, 0x00u, 0x61u, 0x00u, 0x20u, 0x00u,
      0x68u, 0x00u, 0x61u, 0x00u, 0x73u, 0x00u, 0x68u, 0x00u, 0x65u, 0x00u, 0x64u, 0x00u, 0x20u, 0x00u, 0x61u, 0x00u,
      0x6Eu, 0x00u, 0x64u, 0x00u, 0x20u, 0x00u, 0x73u, 0x00u, 0x61u, 0x00u, 0x6Cu, 0x00u, 0x74u, 0x00u, 0x65u, 0x00u,
      0x64u, 0x00u, 0x20u, 0x00u, 0x70u, 0x00u, 0x61u, 0x00u, 0x73u, 0x00u, 0x73u, 0x00u, 0x77u, 0x00u, 0x6Fu, 0x00u,
      0x72u, 0x00u, 0x64u, 0x00u, 0x20u, 0x00u, 0x69u, 0x00u, 0x6Eu, 0x00u, 0x20u, 0x00u, 0x74u, 0x00u, 0x68u, 0x00u,
      0x65u, 0x00u, 0x20u, 0x00u, 0x64u, 0x00u, 0x61u, 0x00u, 0x74u, 0x00u, 0x61u, 0x00u, 0x62u, 0x00u, 0x61u, 0x00u,
      0x73u, 0x00u, 0x65u, 0x00u, 0x20u, 0x00u, 0x73u, 0x00u, 0x65u, 0x00u, 0x6Cu, 0x00u, 0x65u, 0x00u, 0x63u, 0x00u,
      0x74u, 0x00u, 0x65u, 0x00u, 0x64u, 0x00u, 0x20u, 0x00u, 0x69u, 0x00u, 0x6Eu, 0x00u, 0x20u, 0x00u, 0x74u, 0x00u,
      0x68u, 0x00u, 0x65u, 0x00u, 0x20u, 0x00u, 0x6Eu, 0x00u, 0x65u, 0x00u, 0x78u, 0x00u, 0x74u, 0x00u, 0x20u, 0x00u,
      0x73u, 0x00u, 0x74u, 0x00u, 0x65u, 0x00u, 0x70u, 0x00u, 0x2Eu, 0x00u, 0x00u, 0x00u, 0x12u, 0x00u, 0x42u, 0x00u,
      0x61u, 0x00u, 0x63u, 0x00u, 0x6Bu, 0x00u, 0x65u, 0x00u, 0x6Eu, 0x00u, 0x64u, 0x00u, 0x49u, 0x00u, 0x64u, 0x00u,
      0x00u, 0x00u, 0x0Au, 0x00u, 0x00u, 0x00u, 0x00u, 0x10u, 0x00u, 0x44u, 0x00u, 0x61u, 0x00u, 0x74u, 0x00u, 0x61u,
      0x00u, 0x62u, 0x00u, 0x61u, 0x00u, 0x73u, 0x00u, 0x65u, 0x00u, 0x00u, 0x00u, 0x08u, 0x00u, 0x00u, 0x00u, 0x00u,
      0x07u, 0x00u, 0x00u, 0x00u, 0x12u, 0x00u, 0x53u, 0x00u, 0x65u, 0x00u, 0x74u, 0x00u, 0x75u, 0x00u, 0x70u, 0x00u,
      0x4Bu, 0x00u, 0x65u, 0x00u, 0x79u, 0x00u, 0x73u, 0x00u, 0x00u, 0x00u, 0x0Bu, 0x00u, 0x00u, 0x00u, 0x00u, 0x07u,
      0x00u, 0x00u, 0x00u, 0x10u, 0x00u, 0x48u, 0x00u, 0x6Fu, 0x00u, 0x73u, 0x00u, 0x74u, 0x00u, 0x6Eu, 0x00u, 0x61u,
      0x00u, 0x6Du, 0x00u, 0x65u, 0x00u, 0x00u, 0x00u, 0x08u, 0x00u, 0x50u, 0x00u, 0x6Fu, 0x00u, 0x72u, 0x00u, 0x74u,
      0x00u, 0x00u, 0x00u, 0x0Cu, 0x00u, 0x42u, 0x00u, 0x69u, 0x00u, 0x6Eu, 0x00u, 0x64u, 0x00u, 0x44u, 0x00u, 0x4Eu,
      0x00u, 0x00u, 0x00u, 0x18u, 0x00u, 0x42u, 0x00u, 0x69u, 0x00u, 0x6Eu, 0x00u, 0x64u, 0x00u, 0x50u, 0x00u, 0x61u,
      0x00u, 0x73u, 0x00u, 0x73u, 0x00u, 0x77u, 0x00u, 0x6Fu, 0x00u, 0x72u, 0x00u, 0x64u, 0x00u, 0x00u, 0x00u, 0x0Cu,
      0x00u, 0x42u, 0x00u, 0x61u, 0x00u, 0x73u, 0x00u, 0x65u, 0x00u, 0x44u, 0x00u, 0x4Eu, 0x00u, 0x00u, 0x00u, 0x0Cu,
      0x00u, 0x46u, 0x00u, 0x69u, 0x00u, 0x6Cu, 0x00u, 0x74u, 0x00u, 0x65u, 0x00u, 0x72u, 0x00u, 0x00u, 0x00u, 0x18u,
      0x00u, 0x55u, 0x00u, 0x69u, 0x00u, 0x64u, 0x00u, 0x41u, 0x00u, 0x74u, 0x00u, 0x74u, 0x00u, 0x72u, 0x00u, 0x69u,
      0x00u, 0x62u, 0x00u, 0x75u, 0x00u, 0x74u, 0x00u, 0x65u, 0x00u, 0x00u, 0x00u, 0x1Au, 0x00u, 0x53u, 0x00u, 0x65u,
      0x00u, 0x74u, 0x00u, 0x75u, 0x00u, 0x70u, 0x00u, 0x44u, 0x00u, 0x65u, 0x00u, 0x66u, 0x00u, 0x61u, 0x00u, 0x75u,
      0x00u, 0x6Cu, 0x00u, 0x74u, 0x00u, 0x73u, 0x00u, 0x00u, 0x00u, 0x08u, 0x00u, 0x00u, 0x00u, 0x00u, 0x07u, 0x00u,
      0x00u, 0x00u, 0x10u, 0x00u, 0x48u, 0x00u, 0x6Fu, 0x00u, 0x73u, 0x00u, 0x74u, 0x00u, 0x6Eu, 0x00u, 0x61u, 0x00u,
      0x6Du, 0x00u, 0x65u, 0x00u, 0x00u, 0x00u, 0x0Au, 0x00u, 0x00u, 0x00u, 0x00u, 0x20u, 0x00u, 0x6Cu, 0x00u, 0x64u,
      0x00u, 0x61u, 0x00u, 0x70u, 0x00u, 0x3Au, 0x00u, 0x2Fu, 0x00u, 0x2Fu, 0x00u, 0x6Cu, 0x00u, 0x6Fu, 0x00u, 0x63u,
      0x00u, 0x61u, 0x00u, 0x6Cu, 0x00u, 0x68u, 0x00u, 0x6Fu, 0x00u, 0x73u, 0x00u, 0x74u, 0x00u, 0x00u, 0x00u, 0x08u,
      0x00u, 0x50u, 0x00u, 0x6Fu, 0x00u, 0x72u, 0x00u, 0x74u, 0x00u, 0x00u, 0x00u, 0x02u, 0x00u, 0x00u, 0x00u, 0x01u,
      0x85u, 0x00u, 0x00u, 0x00u, 0x0Cu, 0x00u, 0x42u, 0x00u, 0x69u, 0x00u, 0x6Eu, 0x00u, 0x64u, 0x00u, 0x44u, 0x00u,
      0x4Eu, 0x00u, 0x00u, 0x00u, 0x0Au, 0x00u, 0xFFu, 0xFFu, 0xFFu, 0xFFu, 0x00u, 0x00u, 0x00u, 0x18u, 0x00u, 0x42u,
      0x00u, 0x69u, 0x00u, 0x6Eu, 0x00u, 0x64u, 0x00u, 0x50u, 0x00u, 0x61u, 0x00u, 0x73u, 0x00u, 0x73u, 0x00u, 0x77u,
      0x00u, 0x6Fu, 0x00u, 0x72u, 0x00u, 0x64u, 0x00u, 0x00u, 0x00u, 0x0Au, 0x00u, 0xFFu, 0xFFu, 0xFFu, 0xFFu, 0x00u,
      0x00u, 0x00u, 0x0Cu, 0x00u, 0x42u, 0x00u, 0x61u, 0x00u, 0x73u, 0x00u, 0x65u, 0x00u, 0x44u, 0x00u, 0x4Eu, 0x00u,
      0x00u, 0x00u, 0x0Au, 0x00u, 0xFFu, 0xFFu, 0xFFu, 0xFFu, 0x00u, 0x00u, 0x00u, 0x0Cu, 0x00u, 0x46u, 0x00u, 0x69u,
      0x00u, 0x6Cu, 0x00u, 0x74u, 0x00u, 0x65u, 0x00u, 0x72u, 0x00u, 0x00u, 0x00u, 0x0Au, 0x00u, 0xFFu, 0xFFu, 0xFFu,
      0xFFu, 0x00u, 0x00u, 0x00u, 0x18u, 0x00u, 0x55u, 0x00u, 0x69u, 0x00u, 0x64u, 0x00u, 0x41u, 0x00u, 0x74u, 0x00u,
      0x74u, 0x00u, 0x72u, 0x00u, 0x69u, 0x00u, 0x62u, 0x00u, 0x75u, 0x00u, 0x74u, 0x00u, 0x65u, 0x00u, 0x00u, 0x00u,
      0x0Au, 0x00u, 0x00u, 0x00u, 0x00u, 0x06u, 0x00u, 0x75u, 0x00u, 0x69u, 0x00u, 0x64u, 0x00u, 0x00u, 0x00u, 0x12u,
      0x00u, 0x53u, 0x00u, 0x65u, 0x00u, 0x74u, 0x00u, 0x75u, 0x00u, 0x70u, 0x00u, 0x44u, 0x00u, 0x61u, 0x00u, 0x74u,
      0x00u, 0x61u, 0x00u, 0x00u, 0x00u, 0x09u, 0x00u, 0x00u, 0x00u, 0x00u, 0x15u, 0x00u, 0x00u, 0x00u, 0x0Au, 0x00u,
      0x00u, 0x00u, 0x00u, 0x10u, 0x00u, 0x48u, 0x00u, 0x6Fu, 0x00u, 0x73u, 0x00u, 0x74u, 0x00u, 0x6Eu, 0x00u, 0x61u,
      0x00u, 0x6Du, 0x00u, 0x65u, 0x00u, 0x00u, 0x00u, 0x0Au, 0x00u, 0x00u, 0x00u, 0x00u, 0x10u, 0x00u, 0x48u, 0x00u,
      0x6Fu, 0x00u, 0x73u, 0x00u, 0x74u, 0x00u, 0x6Eu, 0x00u, 0x61u, 0x00u, 0x6Du, 0x00u, 0x65u, 0x00u, 0x00u, 0x00u,
      0x0Au, 0x00u, 0x00u, 0x00u, 0x00u, 0x20u, 0x00u, 0x6Cu, 0x00u, 0x64u, 0x00u, 0x61u, 0x00u, 0x70u, 0x00u, 0x3Au,
      0x00u, 0x2Fu, 0x00u, 0x2Fu, 0x00u, 0x6Cu, 0x00u, 0x6Fu, 0x00u, 0x63u, 0x00u, 0x61u, 0x00u, 0x6Cu, 0x00u, 0x68u,
      0x00u, 0x6Fu, 0x00u, 0x73u, 0x00u, 0x74u, 0x00u, 0x00u, 0x00u, 0x0Au, 0x00u, 0x00u, 0x00u, 0x00u, 0x08u, 0x00u,
      0x50u, 0x00u, 0x6Fu, 0x00u, 0x72u, 0x00u, 0x74u, 0x00u, 0x00u, 0x00u, 0x0Au, 0x00u, 0x00u, 0x00u, 0x00u, 0x08u,
      0x00u, 0x50u, 0x00u, 0x6Fu, 0x00u, 0x72u, 0x00u, 0x74u, 0x00u, 0x00u, 0x00u, 0x02u, 0x00u, 0x00u, 0x00u, 0x01u,
      0x85u, 0x00u, 0x00u, 0x00u, 0x0Au, 0x00u, 0x00u, 0x00u, 0x00u, 0x0Cu, 0x00u, 0x42u, 0x00u, 0x69u, 0x00u, 0x6Eu,
      0x00u, 0x64u, 0x00u, 0x44u, 0x00u, 0x4Eu, 0x00u, 0x00u, 0x00u, 0x0Au, 0x00u, 0x00u, 0x00u, 0x00u, 0x0Eu, 0x00u,
      0x42u, 0x00u, 0x69u, 0x00u, 0x6Eu, 0x00u, 0x64u, 0x00u, 0x20u, 0x00u, 0x44u, 0x00u, 0x4Eu, 0x00u, 0x00u, 0x00u,
      0x0Au, 0x00u, 0xFFu, 0xFFu, 0xFFu, 0xFFu, 0x00u, 0x00u, 0x00u, 0x0Au, 0x00u, 0x00u, 0x00u, 0x00u, 0x18u, 0x00u,
      0x42u, 0x00u, 0x69u, 0x00u, 0x6Eu, 0x00u, 0x64u, 0x00u, 0x50u, 0x00u, 0x61u, 0x00u, 0x73u, 0x00u, 0x73u, 0x00u,
      0x77u, 0x00u, 0x6Fu, 0x00u, 0x72u, 0x00u, 0x64u, 0x00u, 0x00u, 0x00u, 0x0Au, 0x00u, 0x00u, 0x00u, 0x00u, 0x1Au,
      0x00u, 0x42u, 0x00u, 0x69u, 0x00u, 0x6Eu, 0x00u, 0x64u, 0x00u, 0x20u, 0x00u, 0x50u, 0x00u, 0x61u, 0x00u, 0x73u,
      0x00u, 0x73u, 0x00u, 0x77u, 0x00u, 0x6Fu, 0x00u, 0x72u, 0x00u, 0x64u, 0x00u, 0x00u, 0x00u, 0x0Au, 0x00u, 0xFFu,
      0xFFu, 0xFFu, 0xFFu, 0x00u, 0x00u, 0x00u, 0x0Au, 0x00u, 0x00u, 0x00u, 0x00u, 0x0Cu, 0x00u, 0x42u, 0x00u, 0x61u,
      0x00u, 0x73u, 0x00u, 0x65u, 0x00u, 0x44u, 0x00u, 0x4Eu, 0x00u, 0x00u, 0x00u, 0x0Au, 0x00u, 0x00u, 0x00u, 0x00u,
      0x0Eu, 0x00u, 0x42u, 0x00u, 0x61u, 0x00u, 0x73u, 0x00u, 0x65u, 0x00u, 0x20u, 0x00u, 0x44u, 0x00u, 0x4Eu, 0x00u,
      0x00u, 0x00u, 0x0Au, 0x00u, 0xFFu, 0xFFu, 0xFFu, 0xFFu, 0x00u, 0x00u, 0x00u, 0x0Au, 0x00u, 0x00u, 0x00u, 0x00u,
      0x0Cu, 0x00u, 0x46u, 0x00u, 0x69u, 0x00u, 0x6Cu, 0x00u, 0x74u, 0x00u, 0x65u, 0x00u, 0x72u, 0x00u, 0x00u, 0x00u,
      0x0Au, 0x00u, 0x00u, 0x00u, 0x00u, 0x0Cu, 0x00u, 0x46u, 0x00u, 0x69u, 0x00u, 0x6Cu, 0x00u, 0x74u, 0x00u, 0x65u,
      0x00u, 0x72u, 0x00u, 0x00u, 0x00u, 0x0Au, 0x00u, 0xFFu, 0xFFu, 0xFFu, 0xFFu, 0x00u, 0x00u, 0x00u, 0x0Au, 0x00u,
      0x00u, 0x00u, 0x00u, 0x18u, 0x00u, 0x55u, 0x00u, 0x69u, 0x00u, 0x64u, 0x00u, 0x41u, 0x00u, 0x74u, 0x00u, 0x74u,
      0x00u, 0x72u, 0x00u, 0x69u, 0x00u, 0x62u, 0x00u, 0x75u, 0x00u, 0x74u, 0x00u, 0x65u, 0x00u, 0x00u, 0x00u, 0x0Au,
      0x00u, 0x00u, 0x00u, 0x00u, 0x1Au, 0x00u, 0x55u, 0x00u, 0x49u, 0x00u, 0x44u, 0x00u, 0x20u, 0x00u, 0x41u, 0x00u,
      0x74u, 0x00u, 0x74u, 0x00u, 0x72u, 0x00u, 0x69u, 0x00u, 0x62u, 0x00u, 0x75u, 0x00u, 0x74u, 0x00u, 0x65u, 0x00u,
      0x00u, 0x00u, 0x0Au, 0x00u, 0x00u, 0x00u, 0x00u, 0x06u, 0x00u, 0x75u, 0x00u, 0x69u, 0x00u, 0x64u, 0x00u, 0x00u,
      0x00u, 0x12u, 0x00u, 0x49u, 0x00u, 0x73u, 0x00u, 0x44u, 0x00u, 0x65u, 0x00u, 0x66u, 0x00u, 0x61u, 0x00u, 0x75u,
      0x00u, 0x6Cu, 0x00u, 0x74u, 0x00u, 0x00u, 0x00u, 0x01u, 0x00u, 0x00u, 0x00u, 0x00u, 0x00u, 0x16u, 0x00u, 0x44u,
      0x00u, 0x69u, 0x00u, 0x73u, 0x00u, 0x70u, 0x00u, 0x6Cu, 0x00u, 0x61u, 0x00u, 0x79u, 0x00u, 0x4Eu, 0x00u, 0x61u,
      0x00u, 0x6Du, 0x00u, 0x65u, 0x00u, 0x00u, 0x00u, 0x0Au, 0x00u, 0x00u, 0x00u, 0x00u, 0x08u, 0x00u, 0x4Cu, 0x00u,
      0x44u, 0x00u, 0x41u, 0x00u, 0x50u, 0x00u, 0x00u, 0x00u, 0x16u, 0x00u, 0x44u, 0x00u, 0x65u, 0x00u, 0x73u, 0x00u,
      0x63u, 0x00u, 0x72u, 0x00u, 0x69u, 0x00u, 0x70u, 0x00u, 0x74u, 0x00u, 0x69u, 0x00u, 0x6Fu, 0x00u, 0x6Eu, 0x00u,
      0x00u, 0x00u, 0x0Au, 0x00u, 0x00u, 0x00u, 0x00u, 0x50u, 0x00u, 0x41u, 0x00u, 0x75u, 0x00u, 0x74u, 0x00u, 0x68u,
      0x00u, 0x65u, 0x00u, 0x6Eu, 0x00u, 0x74u, 0x00u, 0x69u, 0x00u, 0x63u, 0x00u, 0x61u, 0x00u, 0x74u, 0x00u, 0x65u,
      0x00u, 0x20u, 0x00u, 0x75u, 0x00u, 0x73u, 0x00u, 0x65u, 0x00u, 0x72u, 0x00u, 0x73u, 0x00u, 0x20u, 0x00u, 0x75u,
      0x00u, 0x73u, 0x00u, 0x69u, 0x00u, 0x6Eu, 0x00u, 0x67u, 0x00u, 0x20u, 0x00u, 0x61u, 0x00u, 0x6Eu, 0x00u, 0x20u,
      0x00u, 0x4Cu, 0x00u, 0x44u, 0x00u, 0x41u, 0x00u, 0x50u, 0x00u, 0x20u, 0x00u, 0x73u, 0x00u, 0x65u, 0x00u, 0x72u,
      0x00u, 0x76u, 0x00u, 0x65u, 0x00u, 0x72u, 0x00u, 0x2Eu, 0x00u, 0x00u, 0x00u, 0x12u, 0x00u, 0x42u, 0x00u, 0x61u,
      0x00u, 0x63u, 0x00u, 0x6Bu, 0x00u, 0x65u, 0x00u, 0x6Eu, 0x00u, 0x64u, 0x00u, 0x49u, 0x00u, 0x64u, 0x00u, 0x00u,
      0x00u, 0x0Au, 0x00u, 0x00u, 0x00u, 0x00u, 0x08u, 0x00u, 0x4Cu, 0x00u, 0x44u, 0x00u, 0x41u, 0x00u, 0x50u, 0x00u,
      0x00u, 0x00u, 0x0Cu, 0x00u, 0x00u, 0x00u, 0x00u, 0x0Au, 0x43u, 0x6Fu, 0x6Eu, 0x66u, 0x69u, 0x67u, 0x75u, 0x72u,
      0x65u, 0x64u, 0x00u, 0x00u, 0x00u, 0x01u, 0x00u, 0x00u, 0x00u, 0x00u, 0x00u, 0x0Cu, 0x00u, 0x00u, 0x00u, 0x00u,
      0x0Bu, 0x46u, 0x65u, 0x61u, 0x74u, 0x75u, 0x72u, 0x65u, 0x4Cu, 0x69u, 0x73u, 0x74u, 0x00u, 0x00u, 0x00u, 0x0Bu,
      0x00u, 0x00u, 0x00u, 0x00u, 0x00u,
    )
  )
}
